

LeanIXCloudScanBillingPolicyReader = {
    "Version": "2012-10-17",
    "Statement": [
        {
            "Effect": "Allow",
            "Action": [
                "ce:*"
            ],
            "Resource": [
                "*"
            ]
        }
    ]
}

LeanIXCloudScanAdvisorPolicyReader = {
    "Version": "2012-10-17",
    "Statement": [
        {
            "Sid": "VisualEditor0",
            "Effect": "Allow",
            "Action": [
                "support:DescribeTrustedAdvisorCheckResult",
                "support:DescribeTrustedAdvisorChecks"
            ],
            "Resource": "*"
        }
    ]
}

ReadOnlyAccess = {
            "Version": "2012-10-17",
            "Statement": [
                {
                    "Action": [
                        "a4b:Get*",
                        "a4b:List*",
                        "a4b:Search*",
                        "access-analyzer:GetAccessPreview",
                        "access-analyzer:GetAnalyzedResource",
                        "access-analyzer:GetAnalyzer",
                        "access-analyzer:GetArchiveRule",
                        "access-analyzer:GetFinding",
                        "access-analyzer:ListAccessPreviewFindings",
                        "access-analyzer:ListAccessPreviews",
                        "access-analyzer:ListAnalyzedResources",
                        "access-analyzer:ListAnalyzers",
                        "access-analyzer:ListArchiveRules",
                        "access-analyzer:ListFindings",
                        "access-analyzer:ListTagsForResource",
                        "access-analyzer:ValidatePolicy",
                        "acm:Describe*",
                        "acm:Get*",
                        "acm:List*",
                        "acm-pca:Describe*",
                        "acm-pca:Get*",
                        "acm-pca:List*",
                        "amplify:GetApp",
                        "amplify:GetBranch",
                        "amplify:GetJob",
                        "amplify:GetDomainAssociation",
                        "amplify:ListApps",
                        "amplify:ListBranches",
                        "amplify:ListDomainAssociations",
                        "amplify:ListJobs",
                        "apigateway:GET",
                        "application-autoscaling:Describe*",
                        "applicationinsights:Describe*",
                        "applicationinsights:List*",
                        "appmesh:Describe*",
                        "appmesh:List*",
                        "appstream:Describe*",
                        "appstream:List*",
                        "appsync:Get*",
                        "appsync:List*",
                        "autoscaling:Describe*",
                        "autoscaling-plans:Describe*",
                        "autoscaling-plans:GetScalingPlanResourceForecastData",
                        "athena:List*",
                        "athena:Batch*",
                        "athena:Get*",
                        "aws-portal:View*",
                        "backup:Describe*",
                        "backup:Get*",
                        "backup:List*",
                        "batch:List*",
                        "batch:Describe*",
                        "braket:GetDevice",
                        "braket:GetQuantumTask",
                        "braket:SearchDevices",
                        "braket:SearchQuantumTasks",
                        "budgets:Describe*",
                        "budgets:View*",
                        "cassandra:Select",
                        "chatbot:Describe*",
                        "chatbot:Get*",
                        "chime:Get*",
                        "chime:List*",
                        "chime:Retrieve*",
                        "chime:Search*",
                        "chime:Validate*",
                        "cloud9:Describe*",
                        "cloud9:List*",
                        "clouddirectory:List*",
                        "clouddirectory:BatchRead",
                        "clouddirectory:Get*",
                        "clouddirectory:LookupPolicy",
                        "cloudformation:Describe*",
                        "cloudformation:Detect*",
                        "cloudformation:Get*",
                        "cloudformation:List*",
                        "cloudformation:Estimate*",
                        "cloudfront:Get*",
                        "cloudfront:List*",
                        "cloudhsm:List*",
                        "cloudhsm:Describe*",
                        "cloudhsm:Get*",
                        "cloudsearch:Describe*",
                        "cloudsearch:List*",
                        "cloudtrail:Describe*",
                        "cloudtrail:Get*",
                        "cloudtrail:List*",
                        "cloudtrail:LookupEvents",
                        "cloudwatch:Describe*",
                        "cloudwatch:Get*",
                        "cloudwatch:List*",
                        "codeartifact:DescribeDomain",
                        "codeartifact:DescribePackageVersion",
                        "codeartifact:DescribeRepository",
                        "codeartifact:GetAuthorizationToken",
                        "codeartifact:GetDomainPermissionsPolicy",
                        "codeartifact:GetPackageVersionAsset",
                        "codeartifact:GetPackageVersionReadme",
                        "codeartifact:GetRepositoryEndpoint",
                        "codeartifact:GetRepositoryPermissionsPolicy",
                        "codeartifact:ListDomains",
                        "codeartifact:ListPackages",
                        "codeartifact:ListPackageVersionAssets",
                        "codeartifact:ListPackageVersionDependencies",
                        "codeartifact:ListPackageVersions",
                        "codeartifact:ListRepositories",
                        "codeartifact:ListRepositoriesInDomain",
                        "codebuild:BatchGet*",
                        "codebuild:DescribeCodeCoverages",
                        "codebuild:DescribeTestCases",
                        "codebuild:List*",
                        "codecommit:BatchGet*",
                        "codecommit:Describe*",
                        "codecommit:Get*",
                        "codecommit:GitPull",
                        "codecommit:List*",
                        "codedeploy:BatchGet*",
                        "codedeploy:Get*",
                        "codedeploy:List*",
                        "codeguru-profiler:Describe*",
                        "codeguru-profiler:Get*",
                        "codeguru-profiler:List*",
                        "codeguru-reviewer:Describe*",
                        "codeguru-reviewer:Get*",
                        "codeguru-reviewer:List*",
                        "codepipeline:List*",
                        "codepipeline:Get*",
                        "codestar:List*",
                        "codestar:Describe*",
                        "codestar:Get*",
                        "codestar:Verify*",
                        "codestar-notifications:describeNotificationRule",
                        "codestar-notifications:listEventTypes",
                        "codestar-notifications:listNotificationRules",
                        "codestar-notifications:listTagsForResource",
                        "codestar-notifications:ListTargets",
                        "compute-optimizer:DescribeRecommendationExportJobs",
                        "compute-optimizer:GetAutoScalingGroupRecommendations",
                        "compute-optimizer:GetEBSVolumeRecommendations",
                        "compute-optimizer:GetEC2InstanceRecommendations",
                        "compute-optimizer:GetEC2RecommendationProjectedMetrics",
                        "compute-optimizer:GetEnrollmentStatus",
                        "compute-optimizer:GetLambdaFunctionRecommendations",
                        "compute-optimizer:GetRecommendationSummaries",
                        "cognito-identity:Describe*",
                        "cognito-identity:GetCredentialsForIdentity",
                        "cognito-identity:GetIdentityPoolRoles",
                        "cognito-identity:GetOpenIdToken",
                        "cognito-identity:GetOpenIdTokenForDeveloperIdentity",
                        "cognito-identity:List*",
                        "cognito-identity:Lookup*",
                        "cognito-sync:List*",
                        "cognito-sync:Describe*",
                        "cognito-sync:Get*",
                        "cognito-sync:QueryRecords",
                        "cognito-idp:AdminGet*",
                        "cognito-idp:AdminList*",
                        "cognito-idp:List*",
                        "cognito-idp:Describe*",
                        "cognito-idp:Get*",
                        "config:Deliver*",
                        "config:Describe*",
                        "config:Get*",
                        "config:List*",
                        "config:SelectResourceConfig",
                        "connect:List*",
                        "connect:Describe*",
                        "connect:GetFederationToken",
                        "dataexchange:Get*",
                        "dataexchange:List*",
                        "datasync:Describe*",
                        "datasync:List*",
                        "datapipeline:Describe*",
                        "datapipeline:EvaluateExpression",
                        "datapipeline:Get*",
                        "datapipeline:List*",
                        "datapipeline:QueryObjects",
                        "datapipeline:Validate*",
                        "dax:BatchGetItem",
                        "dax:Describe*",
                        "dax:GetItem",
                        "dax:ListTags",
                        "dax:Query",
                        "dax:Scan",
                        "deepcomposer:GetComposition",
                        "deepcomposer:GetModel",
                        "deepcomposer:GetSampleModel",
                        "deepcomposer:ListCompositions",
                        "deepcomposer:ListModels",
                        "deepcomposer:ListSampleModels",
                        "deepcomposer:ListTrainingTopics",
                        "detective:Get*",
                        "detective:List*",
                        "devicefarm:List*",
                        "devicefarm:Get*",
                        "devops-guru:DescribeAccountHealth",
                        "devops-guru:DescribeAccountOverview",
                        "devops-guru:DescribeAnomaly",
                        "devops-guru:DescribeInsight",
                        "devops-guru:DescribeResourceCollectionHealth",
                        "devops-guru:DescribeServiceIntegration",
                        "devops-guru:GetResourceCollection",
                        "devops-guru:ListAnomaliesForInsight",
                        "devops-guru:ListEvents",
                        "devops-guru:ListInsights",
                        "devops-guru:ListNotificationChannels",
                        "devops-guru:ListRecommendations",
                        "devops-guru:SearchInsights",
                        "directconnect:Describe*",
                        "discovery:Describe*",
                        "discovery:List*",
                        "discovery:Get*",
                        "dlm:Get*",
                        "dms:Describe*",
                        "dms:List*",
                        "dms:Test*",
                        "ds:Check*",
                        "ds:Describe*",
                        "ds:Get*",
                        "ds:List*",
                        "ds:Verify*",
                        "dynamodb:BatchGet*",
                        "dynamodb:Describe*",
                        "dynamodb:Get*",
                        "dynamodb:List*",
                        "dynamodb:Query",
                        "dynamodb:Scan",
                        "ec2:Describe*",
                        "ec2:Get*",
                        "ec2:SearchTransitGatewayRoutes",
                        "ec2messages:Get*",
                        "ecr:BatchCheck*",
                        "ecr:BatchGet*",
                        "ecr:Describe*",
                        "ecr:Get*",
                        "ecr:List*",
                        "ecs:Describe*",
                        "ecs:List*",
                        "eks:Describe*",
                        "eks:List*",
                        "elasticache:Describe*",
                        "elasticache:List*",
                        "elasticbeanstalk:Check*",
                        "elasticbeanstalk:Describe*",
                        "elasticbeanstalk:List*",
                        "elasticbeanstalk:Request*",
                        "elasticbeanstalk:Retrieve*",
                        "elasticbeanstalk:Validate*",
                        "elasticfilesystem:Describe*",
                        "elasticloadbalancing:Describe*",
                        "elasticmapreduce:Describe*",
                        "elasticmapreduce:GetBlockPublicAccessConfiguration",
                        "elasticmapreduce:List*",
                        "elasticmapreduce:View*",
                        "elastictranscoder:List*",
                        "elastictranscoder:Read*",
                        "elemental-appliances-software:Get*",
                        "elemental-appliances-software:List*",
                        "es:Describe*",
                        "es:List*",
                        "es:Get*",
                        "es:ESHttpGet",
                        "es:ESHttpHead",
                        "events:Describe*",
                        "events:List*",
                        "events:Test*",
                        "firehose:Describe*",
                        "firehose:List*",
                        "fsx:Describe*",
                        "fsx:List*",
                        "freertos:Describe*",
                        "freertos:List*",
                        "gamelift:List*",
                        "gamelift:Get*",
                        "gamelift:Describe*",
                        "gamelift:RequestUploadCredentials",
                        "gamelift:ResolveAlias",
                        "gamelift:Search*",
                        "glacier:List*",
                        "glacier:Describe*",
                        "glacier:Get*",
                        "globalaccelerator:Describe*",
                        "globalaccelerator:List*",
                        "glue:BatchGetDevEndpoints",
                        "glue:BatchGetJobs",
                        "glue:BatchGetPartition",
                        "glue:BatchGetTriggers",
                        "glue:BatchGetWorkflows",
                        "glue:GetCatalogImportStatus",
                        "glue:GetClassifier",
                        "glue:GetClassifiers",
                        "glue:GetCrawler",
                        "glue:GetCrawlers",
                        "glue:GetCrawlerMetrics",
                        "glue:GetDatabase",
                        "glue:GetDatabases",
                        "glue:GetDataCatalogEncryptionSettings",
                        "glue:GetDataflowGraph",
                        "glue:GetDevEndpoint",
                        "glue:GetDevEndpoints",
                        "glue:GetJob",
                        "glue:GetJobBookmark",
                        "glue:GetJobs",
                        "glue:GetJobRun",
                        "glue:GetJobRuns",
                        "glue:GetMapping",
                        "glue:GetMLTaskRun",
                        "glue:GetMLTaskRuns",
                        "glue:GetMLTransform",
                        "glue:GetMLTransforms",
                        "glue:GetPartition",
                        "glue:GetPartitions",
                        "glue:GetPlan",
                        "glue:GetResourcePolicy",
                        "glue:GetSecurityConfiguration",
                        "glue:GetSecurityConfigurations",
                        "glue:GetTable",
                        "glue:GetTables",
                        "glue:GetTableVersion",
                        "glue:GetTableVersions",
                        "glue:GetTags",
                        "glue:GetTrigger",
                        "glue:GetTriggers",
                        "glue:GetUserDefinedFunction",
                        "glue:GetUserDefinedFunctions",
                        "glue:GetWorkflow",
                        "glue:GetWorkflowRun",
                        "glue:GetWorkflowRunProperties",
                        "glue:GetWorkflowRuns",
                        "glue:ListCrawlers",
                        "glue:ListDevEndpoints",
                        "glue:ListJobs",
                        "glue:ListMLTransforms",
                        "glue:ListTriggers",
                        "glue:ListWorkflows",
                        "greengrass:Get*",
                        "greengrass:List*",
                        "guardduty:Get*",
                        "guardduty:List*",
                        "health:Describe*",
                        "iam:Generate*",
                        "iam:Get*",
                        "iam:List*",
                        "iam:Simulate*",
                        "imagebuilder:Get*",
                        "imagebuilder:List*",
                        "importexport:Get*",
                        "importexport:List*",
                        "inspector:Describe*",
                        "inspector:Get*",
                        "inspector:List*",
                        "inspector:Preview*",
                        "iot:Describe*",
                        "iot:Get*",
                        "iot:List*",
                        "iotanalytics:Describe*",
                        "iotanalytics:List*",
                        "iotanalytics:Get*",
                        "iotanalytics:SampleChannelData",
                        "iotsitewise:Describe*",
                        "iotsitewise:Get*",
                        "iotsitewise:List*",
                        "iotwireless:GetDestination",
                        "iotwireless:GetDeviceProfile",
                        "iotwireless:GetPartnerAccount",
                        "iotwireless:GetServiceEndpoint",
                        "iotwireless:GetServiceProfile",
                        "iotwireless:GetWirelessDevice",
                        "iotwireless:GetWirelessDeviceStatistics",
                        "iotwireless:GetWirelessGateway",
                        "iotwireless:GetWirelessGatewayCertificate",
                        "iotwireless:GetWirelessGatewayFirmwareInformation",
                        "iotwireless:GetWirelessGatewayStatistics",
                        "iotwireless:GetWirelessGatewayTask",
                        "iotwireless:GetWirelessGatewayTaskDefinition",
                        "iotwireless:ListDestinations",
                        "iotwireless:ListDeviceProfiles",
                        "iotwireless:ListPartnerAccounts",
                        "iotwireless:ListServiceProfiles",
                        "iotwireless:ListTagsForResource",
                        "iotwireless:ListWirelessDevices",
                        "iotwireless:ListWirelessGateways",
                        "iotwireless:ListWirelessGatewayTaskDefinitions",
                        "kafka:Describe*",
                        "kafka:List*",
                        "kafka:Get*",
                        "kendra:DescribeDataSource",
                        "kendra:DescribeFaq",
                        "kendra:DescribeIndex",
                        "kendra:DescribeThesaurus",
                        "kendra:ListDataSources",
                        "kendra:ListDataSourceSyncJobs",
                        "kendra:ListFaqs",
                        "kendra:ListIndices",
                        "kendra:ListTagsForResource",
                        "kendra:ListThesauri",
                        "kendra:Query",
                        "kinesisanalytics:Describe*",
                        "kinesisanalytics:Discover*",
                        "kinesisanalytics:Get*",
                        "kinesisanalytics:List*",
                        "kinesisvideo:Describe*",
                        "kinesisvideo:Get*",
                        "kinesisvideo:List*",
                        "kinesis:Describe*",
                        "kinesis:Get*",
                        "kinesis:List*",
                        "kms:Describe*",
                        "kms:Get*",
                        "kms:List*",
                        "lambda:List*",
                        "lambda:Get*",
                        "lex:Get*",
                        "license-manager:Get*",
                        "license-manager:List*",
                        "lightsail:GetActiveNames",
                        "lightsail:GetBlueprints",
                        "lightsail:GetBundles",
                        "lightsail:GetCloudFormationStackRecords",
                        "lightsail:GetDisk",
                        "lightsail:GetDisks",
                        "lightsail:GetDiskSnapshot",
                        "lightsail:GetDiskSnapshots",
                        "lightsail:GetDomain",
                        "lightsail:GetDomains",
                        "lightsail:GetExportSnapshotRecords",
                        "lightsail:GetInstance",
                        "lightsail:GetInstanceMetricData",
                        "lightsail:GetInstancePortStates",
                        "lightsail:GetInstances",
                        "lightsail:GetInstanceSnapshot",
                        "lightsail:GetInstanceSnapshots",
                        "lightsail:GetInstanceState",
                        "lightsail:GetKeyPair",
                        "lightsail:GetKeyPairs",
                        "lightsail:GetLoadBalancer",
                        "lightsail:GetLoadBalancerMetricData",
                        "lightsail:GetLoadBalancers",
                        "lightsail:GetLoadBalancerTlsCertificates",
                        "lightsail:GetOperation",
                        "lightsail:GetOperations",
                        "lightsail:GetOperationsForResource",
                        "lightsail:GetRegions",
                        "lightsail:GetRelationalDatabase",
                        "lightsail:GetRelationalDatabaseBlueprints",
                        "lightsail:GetRelationalDatabaseBundles",
                        "lightsail:GetRelationalDatabaseEvents",
                        "lightsail:GetRelationalDatabaseLogEvents",
                        "lightsail:GetRelationalDatabaseLogStreams",
                        "lightsail:GetRelationalDatabaseMetricData",
                        "lightsail:GetRelationalDatabaseParameters",
                        "lightsail:GetRelationalDatabases",
                        "lightsail:GetRelationalDatabaseSnapshot",
                        "lightsail:GetRelationalDatabaseSnapshots",
                        "lightsail:GetStaticIp",
                        "lightsail:GetStaticIps",
                        "lightsail:Is*",
                        "logs:Describe*",
                        "logs:Get*",
                        "logs:FilterLogEvents",
                        "logs:ListTagsLogGroup",
                        "logs:StartQuery",
                        "logs:StopQuery",
                        "logs:TestMetricFilter",
                        "machinelearning:Describe*",
                        "machinelearning:Get*",
                        "mediaconvert:DescribeEndpoints",
                        "mediaconvert:Get*",
                        "mediaconvert:List*",
                        "mediapackage:List*",
                        "mediapackage:Describe*",
                        "mgh:Describe*",
                        "mgh:GetHomeRegion",
                        "mgh:List*",
                        "mobileanalytics:Get*",
                        "mobilehub:Describe*",
                        "mobilehub:Export*",
                        "mobilehub:Generate*",
                        "mobilehub:Get*",
                        "mobilehub:List*",
                        "mobilehub:Validate*",
                        "mobilehub:Verify*",
                        "mobiletargeting:Get*",
                        "mobiletargeting:List*",
                        "mq:Describe*",
                        "mq:List*",
                        "opsworks:Describe*",
                        "opsworks:Get*",
                        "opsworks-cm:List*",
                        "opsworks-cm:Describe*",
                        "organizations:Describe*",
                        "organizations:List*",
                        "outposts:Get*",
                        "outposts:List*",
                        "personalize:Describe*",
                        "personalize:Get*",
                        "personalize:List*",
                        "pi:DescribeDimensionKeys",
                        "pi:GetResourceMetrics",
                        "polly:Describe*",
                        "polly:Get*",
                        "polly:List*",
                        "polly:SynthesizeSpeech",
                        "qldb:ListLedgers",
                        "qldb:DescribeLedger",
                        "qldb:ListJournalS3Exports",
                        "qldb:ListJournalS3ExportsForLedger",
                        "qldb:DescribeJournalS3Export",
                        "qldb:GetBlock",
                        "qldb:GetDigest",
                        "qldb:GetRevision",
                        "qldb:ListTagsForResource",
                        "ram:Get*",
                        "ram:List*",
                        "rekognition:CompareFaces",
                        "rekognition:Detect*",
                        "rekognition:List*",
                        "rekognition:Search*",
                        "rds:Describe*",
                        "rds:List*",
                        "rds:Download*",
                        "redshift:Describe*",
                        "redshift:GetReservedNodeExchangeOfferings",
                        "redshift:View*",
                        "resource-groups:Get*",
                        "resource-groups:List*",
                        "resource-groups:Search*",
                        "robomaker:BatchDescribe*",
                        "robomaker:Describe*",
                        "robomaker:Get*",
                        "robomaker:List*",
                        "route53:Get*",
                        "route53:List*",
                        "route53:Test*",
                        "route53domains:Check*",
                        "route53domains:Get*",
                        "route53domains:List*",
                        "route53domains:View*",
                        "route53resolver:Get*",
                        "route53resolver:List*",
                        "s3:Get*",
                        "s3:List*",
                        "sagemaker:Describe*",
                        "sagemaker:GetSearchSuggestions",
                        "sagemaker:List*",
                        "sagemaker:Search",
                        "schemas:Describe*",
                        "schemas:Get*",
                        "schemas:List*",
                        "schemas:Search*",
                        "sdb:Get*",
                        "sdb:List*",
                        "sdb:Select*",
                        "secretsmanager:List*",
                        "secretsmanager:Describe*",
                        "secretsmanager:GetResourcePolicy",
                        "securityhub:Describe*",
                        "securityhub:Get*",
                        "securityhub:List*",
                        "serverlessrepo:List*",
                        "serverlessrepo:Get*",
                        "serverlessrepo:SearchApplications",
                        "servicecatalog:Describe*",
                        "servicecatalog:GetApplication",
                        "servicecatalog:GetAttributeGroup",
                        "servicecatalog:List*",
                        "servicecatalog:Scan*",
                        "servicecatalog:Search*",
                        "servicediscovery:Get*",
                        "servicediscovery:List*",
                        "servicequotas:GetAssociationForServiceQuotaTemplate",
                        "servicequotas:GetAWSDefaultServiceQuota",
                        "servicequotas:GetRequestedServiceQuotaChange",
                        "servicequotas:GetServiceQuota",
                        "servicequotas:GetServiceQuotaIncreaseRequestFromTemplate",
                        "servicequotas:ListAWSDefaultServiceQuotas",
                        "servicequotas:ListRequestedServiceQuotaChangeHistory",
                        "servicequotas:ListRequestedServiceQuotaChangeHistoryByQuota",
                        "servicequotas:ListServices",
                        "servicequotas:ListServiceQuotas",
                        "servicequotas:ListServiceQuotaIncreaseRequestsInTemplate",
                        "ses:Get*",
                        "ses:List*",
                        "ses:Describe*",
                        "shield:Describe*",
                        "shield:Get*",
                        "shield:List*",
                        "signer:DescribeSigningJob",
                        "signer:GetSigningPlatform",
                        "signer:GetSigningProfile",
                        "signer:ListSigningJobs",
                        "signer:ListSigningPlatforms",
                        "signer:ListSigningProfiles",
                        "signer:ListTagsForResource",
                        "snowball:Get*",
                        "snowball:Describe*",
                        "snowball:List*",
                        "sns:Get*",
                        "sns:List*",
                        "sns:Check*",
                        "sqs:Get*",
                        "sqs:List*",
                        "sqs:Receive*",
                        "ssm:Describe*",
                        "ssm:Get*",
                        "ssm:List*",
                        "sso:Get*",
                        "sso:Describe*",
                        "sso:List*",
                        "sso:Search*",
                        "sso-directory:Describe*",
                        "sso-directory:List*",
                        "sso-directory:Search*",
                        "states:List*",
                        "states:Describe*",
                        "states:GetExecutionHistory",
                        "storagegateway:Describe*",
                        "storagegateway:List*",
                        "sts:GetAccessKeyInfo",
                        "sts:GetCallerIdentity",
                        "sts:GetSessionToken",
                        "swf:Count*",
                        "swf:Describe*",
                        "swf:Get*",
                        "swf:List*",
                        "synthetics:Describe*",
                        "synthetics:Get*",
                        "synthetics:List*",
                        "tag:Get*",
                        "transfer:Describe*",
                        "transfer:List*",
                        "transfer:TestIdentityProvider",
                        "transcribe:Get*",
                        "transcribe:List*",
                        "trustedadvisor:Describe*",
                        "waf:Get*",
                        "waf:List*",
                        "wafv2:CheckCapacity",
                        "wafv2:Describe*",
                        "wafv2:Get*",
                        "wafv2:List*",
                        "waf-regional:List*",
                        "waf-regional:Get*",
                        "workdocs:Describe*",
                        "workdocs:Get*",
                        "workdocs:CheckAlias",
                        "worklink:Describe*",
                        "worklink:List*",
                        "workmail:Describe*",
                        "workmail:Get*",
                        "workmail:List*",
                        "workmail:Search*",
                        "workspaces:Describe*",
                        "xray:BatchGet*",
                        "xray:Get*"
                    ],
                    "Effect": "Allow",
                    "Resource": "*"
                }
            ]
        }
        
    

leanix_policies = {
    "LeanIXCloudScanBillingPolicyReader": LeanIXCloudScanBillingPolicyReader,
    "LeanIXCloudScanAdvisorPolicyReader": LeanIXCloudScanAdvisorPolicyReader,
    "arn:aws:iam::aws:policy/ReadOnlyAccess": ReadOnlyAccess

}



import boto3
import json
import pandas as pd
import botocore
from typing import List
import click
import numpy as np
from haws.main import logger
from haws.exceptions.authentication import AccessDenied
from haws.services.aws.credential_check import login
from haws.services.lx_api_connector import overwrite_scan_config
from haws.exceptions.authentication import MultipleRoots
from haws.services.setup_helper import update_runtime_settings
from haws.exceptions.billing import *
import os
from haws.services.setup_helper import get_runtime_settings


def get_org_details() -> dict:
    org = boto3.client('organizations')

    org_details = org.describe_organization()['Organization']

    billing_ac = org_details['MasterAccountId']
    billing_ac_arn = org_details['MasterAccountArn']

    org_info = {
        'billing_ac': billing_ac,
        'billing_ac_arn': billing_ac_arn
    }

    return org_info


def is_billing_account(account_id: str):
    org_info = get_org_details()
    billing_ac = org_info['billing_ac']

    if billing_ac == account_id:
        logger.info(f'Account {account_id} is the billing account')

        out = {
            "is_billing_account": True,
            "billing_ac": billing_ac,
            "scan_agent_account_id": account_id
        }

        update_runtime_settings({"billing_account_id": billing_ac})

    else:
        logger.warning(
            f'{account_id} [danger]is not billing account[/danger]', extra={
                "markup": True})
        logger.info(f'{billing_ac} is the billing account')
        out = {
            "is_billing_account": False,
            "billing_ac": billing_ac,
            "scan_agent_account_id": account_id
        }
        payload = [
            {
                "id": 'aws.'+str(billing_ac),
                "name": 'aws.billingaccount',
                "type": "aws",
                "data": {
                    "AWSAccessKeyId": "<AWSKEY>",
                    "AWSSecretAccessKey": "",
                    "SubscriptionID": billing_ac
                },
                "active": True
            }
        ]
        logger.error(f"[danger]the used IAM role doesnt have sufficient permissions to access information about the AWS organization structure.\n To allow the full functioning of this scirpt please create IAM role from:[/danger] {billing_ac}", extra={
                     "markup": True})
        logger.info(f'[info]already writing discovered billing account[/info] {billing_ac} [info]to scan config...[/info]', extra={
            "markup": True})
        overwrite_scan_config(scan_config=payload)

        
        raise AccessDenied

    return out


def get_parents(parents: List[str], df: pd.DataFrame):
    org = boto3.client('organizations')
    org_chart = dict()

    for parent in parents:
        collector = list()
        ous = org.list_organizational_units_for_parent(
            ParentId=parent)['OrganizationalUnits']

        if len(ous) != 0:  # only if children exist
            for child in ous:
                ou_name = child['Name']
                ou_id = child['Id']
                ou_arn = child['Arn']

                package = {
                    'parent_id': parent,
                    'child_id': ou_id,
                    'child_name': ou_name,
                    'child_arn': ou_arn
                }
                df = df.append(package, ignore_index=True)
                collector.append(ou_id)

            org_chart[parent] = collector

    return df, org_chart


def traverse_ous(root_id: str):

    org_chart = list()
    data = pd.DataFrame(
        columns=['parent_id', 'child_id', 'child_name', 'child_arn'])
    circuit_breaker = False
    parent = [root_id]

    while not circuit_breaker:
        """
            1. for all parents get children
            2. get children for parents with children
            3. continue until all selected parents dont have any children
        """
        if parent == [root_id]:
            package = {
                'parent_id': root_id,
                'child_id': root_id,
                'child_name': "root",
                'child_arn': np.nan
            }
            data = data.append(package, ignore_index=True)
            data, new_children = get_parents(parents=parent, df=data)
            parent = new_children

        else:
            keys = list(parent.keys())
            col = list()
            super_parent = parent
            no_child_counter = 0
            for key in keys:
                data, parent = get_parents(super_parent[key], data)

                if len(parent) == 0:
                    no_child_counter += 1

            if no_child_counter == len(keys):
                circuit_breaker = True

        if len(parent) != 0:
            org_chart.append(parent)
    cwd = os.getcwd()
    file_path = cwd+'/ou_chart.pkl'
    data.to_pickle(file_path)

    return data


def get_root():
    org = boto3.client('organizations')
    try:
        root = org.list_roots()['Roots']
        root_id = None

        if len(root) > 1:
            logger.error(f'Found {len(root)} roots. Can only handle one root.')
            raise MultipleRoots(
                'found multiple roots. Can only handle one root')

        elif len(root) == 1:
            root_id = root[0]['Id']
    except org.exceptions.AccessDeniedException:
        logger.warning("[danger]user doesnt have sufficient permissions to access roots", extra={
                       "markup": True})
        raise AccessDenied('User doesnt have the sufficient permissions')

    return root_id


def get_accounts_for_org_chart(org: pd.DataFrame):
    org_client = boto3.client('organizations')
    parents = list(org['child_id'].unique())
    account_map = pd.DataFrame(
        columns=['parent_id', 'account_id', 'account_arn', 'account_email', 'account_name'])

    for parent in parents:
        res = org_client.list_accounts_for_parent(ParentId=parent)['Accounts']
        if len(res) != 0:
            for account in res:

                if account['Status'] == "ACTIVE":
                    account_id = account['Id']
                    account_arn = account['Arn']
                    account_email = account['Email']
                    account_name = account['Name']

                    package = {
                        'parent_id': parent,
                        'account_id': account_id,
                        'account_arn': account_arn,
                        'account_email': account_email,
                        'account_name': account_name

                    }

                    account_map = account_map.append(
                        package, ignore_index=True)

    total = pd.merge(org, account_map, how='left',
                     left_on='child_id', right_on='parent_id')
    cwd = os.getcwd()
    file_path = cwd+'/entire_org.pkl'
    total.to_pickle(file_path)
    logger.info(
        f'saved traversed org chart @ {file_path}.//[grey italic] use [bold]pandas[/bold] to open [/grey italic]', extra={"markup": True})
    return total


def get_relevant_accounts(org_df: pd.DataFrame):
    filter_words = 'sandbox|prod|test|^qa$|root'
    org_clean = org_df[org_df.account_id.notnull()].copy()
    org_clean = org_clean[org_clean.account_name.str.contains(
        pat=filter_words, case=False)]
    collector = list()

    # already add billing account
    billing_account_id = get_runtime_settings()['billing_account_id']
    billing_account = {
        "id": 'aws.'+str(billing_account_id),
        "name": 'aws.billingaccount',
        "type": "aws",
        "data": {
                "AWSAccessKeyId": "<AWSKEY>",
            "AWSSecretAccessKey": "",
            "SubscriptionID": billing_account_id
        },
        "active": True
    }
    collector.append(billing_account)

    for index, row in org_clean.iterrows():
        account = {
            "id": 'aws.'+str(row['account_id']),
            "name": 'aws.'+str(row['account_name']).lower()+str(index),
            "type": "aws",
            "data": {
                "AWSAccessKeyId": "<AWSKEY>",
                    "AWSSecretAccessKey": "",
                    "SubscriptionID": row['account_id']
            },
            "active": True
        }

        collector.append(account)

    return collector


def run_org_check():
    login_info = login()
    account_id = login_info['account']

    if is_billing_account(account_id=account_id):
        root_id = get_root()
        org_list = traverse_ous(root_id=root_id)
        org_df = get_accounts_for_org_chart(org=org_list)
        payload = get_relevant_accounts(org_df=org_df)
        overwrite_scan_config(scan_config=payload)
    else:
        raise BillingAccountInavailable(
            "IAM role not created within billing account")
        logger.warning(
            "[danger]No billing account found[/danger]", extra={"markup": True})



import boto3
import json
import botocore
import click
import re
import os
from rich.console import Console
from typing import List
from haws.config.leanix_policies import leanix_policies
from haws.main import logger
from haws.services.aws.credential_check import login
from haws.exceptions.authentication import UnauthenticatedUserCredentials, FailedPolicyCheck


def check_user_policies(username: str):
    """
        gets all AWS policies attached to a user, fetched by his/her AWS username, and checks whether the LeanIX CI Policies
        were created. This check does not pick up policies via group assignment

    """

    iam = boto3.client('iam')
    pattern = re.compile(
        'LeanIXCloudScanAdvisorPolicyReader|LeanIXCloudScanBillingPolicyReader|arn:aws:iam::aws:policy/ReadOnlyAccess')
    policies = iam.list_attached_user_policies(UserName=username)
    user_policies = list()

    for policy in policies['AttachedPolicies']:
        policy_arn = policy['PolicyArn']
        user_policies.append(policy_arn)

    return user_policies


def check_user_group_policies(username: str):
    iam = boto3.client('iam')
    user_groups_list = iam.list_groups_for_user(UserName=username)['Groups']

    all_attached_groups = list()
    for group in user_groups_list:
        all_attached_groups.append(group['GroupName'])

    group_policies = list()
    for group_policy in all_attached_groups:
        policies = iam.list_attached_group_policies(
            GroupName=str(group_policy))['AttachedPolicies']

        for policy in policies:
            group_policies.append(policy['PolicyArn'])

    return group_policies


def get_all_user_policies(username: str):
    user_policies = check_user_policies(username=username)
    group_assigned_policies = check_user_group_policies(username=username)

    if len(user_policies) == 0:
        logger.info(
            f'[info]No policies assigned to user {username} directly[/info]', extra={"markup": True})

    else:

        logger.info(
            f'[info]Policies assigned to user [white bold]{username}[/white bold] directly: {user_policies}[/info]', extra={"markup": True})

    if len(group_assigned_policies) == 0:

        logger.info(
            f'[info]No policies assigned via group adherence[/info]', extra={"markup": True})
    else:
        logger.info(
            f'[info]Policies assigned via group: {group_assigned_policies}[/info]', extra={"markup": True})

    if len(user_policies) == 0:
        all_user_policies = group_assigned_policies
    else:
        all_user_policies = user_policies + group_assigned_policies

    return all_user_policies


def authenticated_scan_policies(username: str):
    """
        gets all AWS policies attached to a user, fetched by his/her AWS username, and checks whether the LeanIX CI Policies
        were created and authenticates / verifies the credentials, if it fails to query the IAM console.
    """

    try:
        user_policies = get_all_user_policies(username=username)
    except botocore.exceptions.NoCredentialsError:
        logger.error(
            '[danger]User not authenticated.[/danger]', extra={"markup": True})
        user_policies = None
        raise UnauthenticatedUserCredentials("User is not authenticated")

    return user_policies


def compare_with_leanix(policies: dict):
    """
        compares specified policy permssions with LeanIX's prescribed policy permission set under
        requirements.py
    """

    output = dict()
    for policy, data in policies.items():

        if data['exists']:
            permission_check = data['req_permissions'].items(
            ) == data['aws_permission'].items()
            output[policy] = {
                'exists': data['exists'],
                'permission_check': permission_check,
                'aws_permission': data['aws_permission'],
                'req_permission': data['req_permissions']
            }
        else:
            if ('aws_permission' in data) and (data['req_permissions'] is not None):
                output[policy] = {
                    'exists': data['exists'],
                    'aws_permission': data['aws_permission'],
                    'req_permission': data['req_permissions'],
                    'permission_check': False

                }
            else:
                output[policy] = {
                    'exists': data['exists'],
                    'aws_permission': None,
                    'req_permission': data['req_permissions'],
                    'permission_check': False

                }

    return output


def get_policy_permissions(policies: dict):
    """
        retrieves the permissions set for a list of policies.
    """

    iam = boto3.client('iam')
    policy_container = dict()
    for policy, data in policies.items():
        if data['exists']:
            policy_version = iam.get_policy(PolicyArn=policy)[
                'Policy']['DefaultVersionId']
            permission = iam.get_policy_version(
                PolicyArn=policy,
                VersionId=policy_version)['PolicyVersion']['Document']

            policy_container[policy] = {
                'aws_permission': permission, 'exists': data['exists'], 'req_permissions': data['req_permissions']}
        else:
            policy_container[policy] = {
                'req_permissions': data['req_permissions'], 'exists': False}

    return policy_container


def filter_policies(policies: List[str], leanix_policies: dict = leanix_policies) -> dict:
    """
        checks if policy names defined in leanix_policies.py are contained in AWS Scan User. 
        see https://dev.leanix.net/docs/cloud-intelligence#section-aws-user-setup for LeanIX requried policies.
    """

    regex_collector = dict()
    filtered_policies = dict()

    for policy_name, permissions in leanix_policies.items():
        string_match = re.compile(policy_name)
        regex_collector[policy_name] = {
            'regex': string_match, 'permissions': permissions}

    for policy in policies:

        count = 0
        for policy_arn, data in regex_collector.items():
            if re.search(data['regex'], policy):
                count += 1
                filtered_policies[policy] = {
                    'exists': True, 'req_permissions': data['permissions']}
        if count == 0:
            filtered_policies[policy] = {
                'exists': False, 'req_permissions': None}

    return filtered_policies


def verify_permissions(policies: List[str]) -> dict:
    """
        processes a set of policies and checks their containing permissions against the required LeanIX permissions stipulated 
        under leanix_policies.py. 

        :param policies list
        :returns dict:
        {
            "policy": {
                "exists": Bool - whether LeanIX policy exists in User policies
                "permission_check": Bool - True if permissions match LeanIX permissions; False if not
                "req_permission": required permissions; returned if permission check fails
            }
        }

    """

    filtered_policies = filter_policies(policies=policies)
    permissions = get_policy_permissions(filtered_policies)
    validated_permissions = compare_with_leanix(permissions)

    return validated_permissions


def create_policy_report(policy_checks: dict):
    num_healthchecks = 0
    cwd = os.getcwd()
    filename = cwd+'/report.txt'
    failed_checks = 0
    passed_checks = 0

    with open(filename, 'w') as fh:
        console = Console(file=fh, width=75)
        console.rule("Policy Checks")

        for policy, data in policy_checks.items():
            if (data['exists'] and data['permission_check']):
                console.print(f':white_check_mark: {policy} is set up correctly')
                passed_checks += 1
                num_healthchecks +=1
            elif (data['exists'] and not data['permission_check']):
                failed_checks += 1
                num_healthchecks +=1
                console.print(
                        f':stop_sign: {policy} does not comply with the naming convention or the wrong policy(-ies) was attached')
            elif (not data['exists']) and (not data['permission_check']):
                console.print(
                        f':information_source: {policy} was found but is not mandatory for the LeanIX Scan Agent')
                    
                    
        console.rule()

        logger.info('[bold]AWS Policy Checks[/bold]', extra={"markup": True})
        if passed_checks == num_healthchecks:
            console.print(
                f'[bold]:white_check_mark: {passed_checks}/{num_healthchecks} checks passed[/bold]')
            logger.info(
                f'[bold]:white_check_mark: {passed_checks}/{num_healthchecks} checks passed[/bold]', extra={"markup": True})
        else:
            logger.info(
                f'[bold]:white_check_mark: {passed_checks}/{num_healthchecks} checks passed[/bold]', extra={"markup": True})
            logger.warning(
                f'[bold red]:stop_sign: {failed_checks}/{num_healthchecks} checks failed[/bold red]. please see the details: [bold]{filename}[/bold]', extra={"markup": True})
            console.log(
                f'[bold red]:stop_sign: {failed_checks}/{num_healthchecks} checks failed[/bold red].')
            raise FailedPolicyCheck(
                f"{failed_checks}/{num_healthchecks} checks failed")


def run_policy_check():
    login_info = login()

    if login_info['check']:
        user_policies = authenticated_scan_policies(
            username=login_info['username'])
        policy_checks = verify_permissions(policies=user_policies)

    create_policy_report(policy_checks=policy_checks)



class UnauthenticatedUserCredentials(Exception):
    pass

class FailedPolicyCheck(Exception):
    pass


class InvalidUserCredentials(Exception):
    pass


class GeneralAuthError(Exception):
    pass

class NoRuntimeSettings(Exception):
    pass

class MultipleRoots(Exception):
    pass

class AccessDenied(Exception):
    pass


import json
import requests
import pandas as pd
from typing import List
from haws.services.setup_helper import get_runtime_settings
from haws.main import logger


# Get the bearer token - see https://dev.leanix.net/v4.0/docs/authentication

def authenticate():
    settings = get_runtime_settings()
    api_token = settings['lx_apitoken']
    lx_host = settings['lx_host']
    auth_url = f'https://{lx_host}.leanix.net/services/mtm/v1/oauth2/token'

    response = requests.post(auth_url, auth=('apitoken', api_token),
                             data={'grant_type': 'client_credentials'})

    try:
        response.raise_for_status()
        access_token = response.json()['access_token']
        bearer_token = 'Bearer ' + access_token
        logger.info(
            f'[bold green]Authenticated with LeanIX API Token[/]', extra={"markup": True})
    except requests.exceptions.HTTPError as err:
        logger.exception(err, exc_info=True)
        logger.error(f'Shutting down due to invalid LeanIX API credentials')

    return bearer_token


def overwrite_scan_config(scan_config: List[dict]):
    bearer_token = authenticate()
    settings = get_runtime_settings()
    lx_host = settings['lx_host']

    endpoint = f"https://{lx_host}.leanix.net/services/cloudockit-connector/v1/configurations/overwrite"
    header = {
        'Authorization': bearer_token,
        'Content-Type': 'application/json'
    }
    
    json_data = json.dumps(scan_config)

    response = requests.post(url=endpoint, headers=header, data=json_data)
    try:
        response.raise_for_status()
        if response.status_code == 200:
            logger.info(
                ':tada:[bold green] LeanIX Scan config successfully changed.[bold green]', extra={"markup": True})
    except requests.exceptions.HTTPError as err:
        logger.exception(err, exc_info=True)



import boto3
import botocore
import json
import re
import click
import os
from haws.main import logger
from os import path
from haws.main import runtime
from rich.prompt import Prompt
from haws.services.setup_helper import get_runtime_settings
from pathlib import Path
from haws.exceptions.authentication import InvalidUserCredentials, NoRuntimeSettings,GeneralAuthError


def get_user_credentials():

    # click.prompt(text="Your AWS ID: ", type=str)
    id = Prompt.ask("[blue bold]Your AWS ID: [/blue bold]")
    # click.prompt(text="Your AWS Key: ", type=str, hide_input=True)
    key = Prompt.ask("[blue bold]Your AWS Key: [/blue bold]", password=True)

    return id, key


def verify_credentials(aws_access_key_id: str, aws_secret_access_key: str, extended: bool = False):
    pattern = re.compile('user/(.*)')
    sts = boto3.client('sts',
                       aws_access_key_id=aws_access_key_id,
                       aws_secret_access_key=aws_secret_access_key)

    try:
        res = sts.get_caller_identity()
        if (not os.getenv('AWS_ACCESS_KEY_ID')) or (not os.getenv('AWS_SECRET_ACCESS_KEY')):
            logger.info("[info]credentials are valid[/info]",
                    extra={"markup": True})
            os.environ['AWS_ACCESS_KEY_ID'] = aws_access_key_id
            os.environ['AWS_SECRET_ACCESS_KEY'] = aws_secret_access_key
            
        if not extended:
            return True
        else:
            username = re.search(pattern, res['Arn']).group(1)
            out = {
                "check": True,
                "user_arn": res['Arn'],
                "account": res['Account'],
                "username": username
            }
            return out
    except botocore.exceptions.ClientError:
        if not extended:
            return False
            raise InvalidUserCredentials("Invalid user credentials")
        else:
            logger.error('[danger]credentials invalid.[/danger]',
                         extra={"markup": True})
            raise InvalidUserCredentials("Invalid user credentials")

    except Exception as e:
        logger.exception(e, exc_info=True)
        if not extended:
            return False
            raise GeneralAuthError(e)
            
        else:
            username = re.search(pattern, res['Arn']).group(1)
            out = {
                "check": False,
                "user_arn": res['Arn'],
                "account": res['Account'],
                "username": username
            }
            raise GeneralAuthError(e)


def login():
    if not path.exists(runtime):
        print(runtime)
        logger.error('[danger]Did not find any runtime config.', extra={
                     "markup": True})
        raise NoRuntimeSettings("no runtime settings")
    else:
        settings = get_runtime_settings()
        aws_id = settings['aws_id']
        aws_key = settings['aws_key']

    check = verify_credentials(
        aws_access_key_id=aws_id, aws_secret_access_key=aws_key, extended=True)

    return check



import click
import os
import io
import logging
import sys
import datetime
from rich.console import Console
from rich.padding import Padding
from rich.logging import RichHandler
from rich.theme import Theme
from pathlib import Path

root_dir = str(Path(__file__).parent.absolute())
runtime = root_dir + '/config/runtime.json'

plugin_folder = os.path.join(os.path.dirname(__file__), 'commands')
logger_config = os.path.dirname(__file__) + '/config/logger.ini'
health_log = os.path.dirname(__file__) + '/services/healthcheck.log'

logger_console = Console(theme=Theme().read(
    logger_config), log_time_format='%b-%d-%y %H:%M:%S')
logger = logging.getLogger(__name__)
f_handler = logging.FileHandler(health_log, mode='w+')
f_formatter = logging.Formatter(
    '%(levelname)s-%(asctime)s - %(message)s - line %(lineno)d - %(filename)s', datefmt='%b-%d-%y %H:%M:%S')

f_handler.setFormatter(f_formatter)

logger.addHandler(f_handler)
logger.addHandler(RichHandler(console=logger_console, rich_tracebacks=True))
logger.setLevel(logging.INFO)


class AWSScanner(click.MultiCommand):

    def list_commands(self, ctx):
        rv = ['setup', 'run']
        # for filename in os.listdir(plugin_folder):
        #     if filename.endswith('.py') and not filename.startswith('__'):
        #         rv.append(filename[:-3])
        # rv.sort()
        return rv

    def get_command(self, ctx, name):
        ns = {}
        fn = os.path.join(plugin_folder, name + '.py')
        with open(fn) as f:
            code = compile(f.read(), fn, 'exec')
            eval(code, ns, ns)
        return ns['cli']

    def format_help(self, ctx, formatter):
        sio = io.StringIO()
        console = Console(file=sio, force_terminal=True)
        console.print(
            ":tornado: [bold blue] LEANIX AWS HEALTHCHECKER", justify="center")
        # console.print("\n")
        console.print(
            "[bold]Description[/bold]: [italic]A Python CLI to sanity check the AWS scanning config", justify="center")
        console.print(
            "[bold]Support[/bold]:[italic]support@leanix.net", justify="center")
        console.print("[bold magenta] Commands",)
        for cmd in self.list_commands(ctx):
            console.print(f"[bold blue]{cmd} [/bold blue] ")
        formatter.write(sio.getvalue())


@click.group(cls=AWSScanner)
@click.pass_context
def cli(ctx):
    pass


if __name__ == '__main__':
    cli()



import json
import re
from rich.prompt import Prompt
from pathlib import Path

root_dir = str(Path(__file__).parent.parent.absolute())
runtime = root_dir + '/config/runtime.json'


def get_runtime_settings(filename: str = runtime):

    with open(filename, 'r') as fh:
        settings = json.load(fh)

    return settings


def update_runtime_settings(data: dict, filename: str = runtime):
    current_settings = get_runtime_settings(filename=filename)

    for key, value in data.items():
        current_settings[key] = value

    with open(runtime, 'w') as fh:
        json.dump(export, fh, indent=4)


def setup_cli():
    aws_id = Prompt.ask("[blue bold]Your AWS ID: [/blue bold]")
    aws_key = key = Prompt.ask(
        "[blue bold]Your AWS Key: [/blue bold]", password=True)
    lx_apitoken = Prompt.ask("[blue bold]Your LeanIX API Token: [/blue bold]")
    lx_host = Prompt.ask("[blue bold]Your workspace url: [/blue bold]")

    pattern = re.compile(r'https://(.*).leanix')
    lx_host = re.search(pattern, lx_host).group(1)

    export = {
        'aws_id': aws_id,
        'aws_key': aws_key,
        'lx_host': lx_host,
        'lx_apitoken': lx_apitoken
    }

    with open(runtime, 'w') as fh:
        json.dump(export, fh, indent=4)



import click
from haws.services.aws.policy_check import *
from haws.services.aws.organization_check import *
from haws.exceptions.authentication import *
from haws.services.setup_helper import setup_cli
from rich.prompt import Confirm
import sys
from pathlib import Path
import os
from os import path
from haws.main import logger, runtime


@click.command()
@click.option('--save-runtime',is_flag=True, default=False)
def cli(save_runtime):
    try:
        run_policy_check()
        run_org_check()
    except (UnauthenticatedUserCredentials, NoRuntimeSettings, InvalidUserCredentials):
        rerun = Confirm.ask("Do you want to setup the healthchcker? [y/n]")
        if rerun:
            setup_cli()
        else:
            if not save_runtime:
                if path.exists(runtime):
                    os.remove(runtime)
                    logger.info("[info]removed runtime.json [/info]",
                                extra={"markup": True})
            logger.info("[info]shutting down[/info]", extra={"markup": True})
            sys.exit()
    except (MultipleRoots, GeneralAuthError):
        if not save_runtime:
            if path.exists(runtime):
                os.remove(runtime)
                logger.info("[info] removed runtime.json [/info]",
                            extra={"markup": True})
        logger.info("[info]shutting down[/info]", extra={"markup": True})
        sys.exit()

    except (BillingAccountInavailable,AccessDenied):
        if not save_runtime:
            if path.exists(runtime):
                os.remove(runtime)
                logger.info("[info]removed runtime config [/info]",
                            extra={"markup": True})
        logger.info("[info]shutting down[/info]", extra={"markup": True})
        sys.exit()
    except FailedPolicyCheck:
        pass



from setuptools import find_packages, setup


def read_requirements():
    with open("requirements.txt", "r") as req:
        content = req.read()
        requirements = content.split("\n")

    return requirements


setup(
    name="haws",
    description="A CLI to sanity check the AWS setup for LeanIX Cloud Intelligence Scans",
    version="1.0.0",
    url="https://github.com/vg-leanix/aws_sancheck",
    author="Vincent Groves",
    author_email="vincent.groves@leanix.net",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Environment :: Console",
        "Intended Audience :: Customer Service",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.9",
        "License :: OSI Approved :: Apache Software License"


    ],
    python_requires='>=3.5',
    include_package_data=True,
    install_requires=read_requirements(),
    entry_points="""
        [console_scripts]
        haws=haws.main:cli
    """,
    license='Apache 2.0'
)
